@@ -1,12 +1,12 @@
 from .select import Select
 from .common_table_expression import CommonTableExpression
 from .union import Union
-from .constant import Constant, NullConstant
+from .constant import Constant, NullConstant, SpecialConstant
 from .identifier import Identifier
 from .star import Star
 from .join import Join
 from .type_cast import TypeCast
 from .tuple import Tuple
-from .operation import Operation, BinaryOperation, UnaryOperation, BetweenOperation, Function
+from .operation import Operation, BinaryOperation, UnaryOperation, BetweenOperation, Function, WindowFunction
 from .order_by import OrderBy
 from .parameter import Parameter
