@@ -2,9 +2,11 @@ from .lexer import MindsDBLexer
 from .parser import MindsDBParser
 
 from .create_view import CreateView
-from .create_integration import CreateIntegration
+from .create_datasource import CreateDatasource
 from .create_predictor import CreatePredictor
 from .drop_predictor import DropPredictor
 from .retrain_predictor import RetrainPredictor
 from .drop_integration import DropIntegration
+from .drop_datasource import DropDatasource
+from .drop_dataset import DropDataset
 from .latest import Latest
\ No newline at end of file
