@@ -1,35 +1,43 @@
 import re
 from sly import Lexer
 
+RESERVED_KEYWORDS = ['DATABASE']
 
 class SQLLexer(Lexer):
     reflags = re.IGNORECASE
     ignore = ' \t\n\r'
 
     tokens = {
-        USE, CREATE, DESCRIBE,
+        USE, DROP, CREATE, DESCRIBE,
 
         # Misc
-        SET, AUTOCOMMIT, START, TRANSACTION, COMMIT, ROLLBACK, ALTER, EXPLAIN,
+        SET, START, TRANSACTION, COMMIT, ROLLBACK, ALTER, EXPLAIN,
+        ISOLATION, LEVEL, REPEATABLE, READ, WRITE, UNCOMMITTED, COMMITTED,
+        SERIALIZABLE, ONLY, CONVERT, USING,
 
-        # SHOW Keywords
+        # SHOW Keywords/DDL Keywords
 
-        SHOW, SCHEMAS, DATABASES, TABLES, TABLE, FULL,
-        VARIABLES, SESSION, STATUS,
+        SHOW, SCHEMAS, SCHEMA, DATABASES, DATABASE, TABLES, TABLE, FULL,
+        VIEW, VARIABLES, SESSION, STATUS,
         GLOBAL, PROCEDURE, FUNCTION, INDEX, WARNINGS,
         ENGINES, CHARSET, COLLATION, PLUGINS, CHARACTER,
+        PERSIST, PERSIST_ONLY, DEFAULT,
 
+        IF_EXISTS,
 
         # SELECT Keywords
         WITH, SELECT, DISTINCT, FROM, WHERE, AS,
         LIMIT, OFFSET, ASC, DESC, NULLS_FIRST, NULLS_LAST,
         GROUP_BY, HAVING, ORDER_BY,
-        STAR,
+        STAR, FOR, UPDATE,
 
         JOIN, INNER, OUTER, CROSS, LEFT, RIGHT, ON,
 
         UNION, ALL,
 
+        # DML
+        INSERT, INTO, VALUES,
+
         # Special
         DOT, COMMA, LPAREN, RPAREN, PARAMETER,
 
@@ -37,20 +45,30 @@ class SQLLexer(Lexer):
         PLUS, MINUS, DIVIDE, MODULO,
         EQUALS, NEQUALS, GREATER, GEQ, LESS, LEQ,
         AND, OR, NOT, IS,
-        IN, LIKE, CONCAT, BETWEEN, WINDOW,
+        IN, LIKE, CONCAT, BETWEEN, WINDOW, OVER, PARTITION_BY,
 
         # Data types
-        CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE}
+        CAST, ID, INTEGER, FLOAT, QUOTE_STRING, DQUOTE_STRING, NULL, TRUE, FALSE}
 
     # Misc
     SET = r'\bSET\b'
-    AUTOCOMMIT = r'\bAUTOCOMMIT\b'
     START = r'\bSTART\b'
     TRANSACTION = r'\bTRANSACTION\b'
     COMMIT = r'\bCOMMIT\b'
     ROLLBACK = r'\bROLLBACK\b'
     EXPLAIN = r'\bEXPLAIN\b'
     ALTER = r'\bALTER\b'
+    ISOLATION = r'\bISOLATION\b'
+    LEVEL = r'\bLEVEL\b'
+    REPEATABLE = r'\bREPEATABLE\b'
+    READ = r'\bREAD\b'
+    WRITE = r'\bWRITE\b'
+    UNCOMMITTED = r'\bUNCOMMITTED\b'
+    COMMITTED = r'\bCOMMITTED\b'
+    SERIALIZABLE = r'\bSERIALIZABLE\b'
+    ONLY = r'\bONLY\b'
+    CONVERT = r'\bCONVERT\b'
+    USING = r'\bUSING\b'
 
     USE = r'\bUSE\b'
     DESCRIBE = r'\bDESCRIBE\b'
@@ -58,9 +76,12 @@ class SQLLexer(Lexer):
     # SHOW
     SHOW = r'\bSHOW\b'
     SCHEMAS = r'\bSCHEMAS\b'
+    SCHEMA = r'\bSCHEMA\b'
     DATABASES = r'\bDATABASES\b'
+    DATABASE = r'\bDATABASE\b'
     TABLES = r'\bTABLES\b'
     TABLE = r'\bTABLE\b'
+    VIEW = r'\bVIEW\b'
     FULL = r'\bFULL\b'
     VARIABLES = r'\bVARIABLES\b'
     SESSION = r'\bSESSION\b'
@@ -69,6 +90,7 @@ class SQLLexer(Lexer):
     PROCEDURE = r'\bPROCEDURE\b'
     FUNCTION = r'\bFUNCTION\b'
     INDEX = r'\bINDEX\b'
+    DROP = r'\bDROP\b'
     CREATE = r'\bCREATE\b'
     WARNINGS = r'\bWARNINGS\b'
     ENGINES = r'\bENGINES\b'
@@ -76,7 +98,10 @@ class SQLLexer(Lexer):
     CHARACTER = r'\bCHARACTER\b'
     COLLATION = r'\bCOLLATION\b'
     PLUGINS = r'\bPLUGINS\b'
-
+    PERSIST = r'\bPERSIST\b'
+    PERSIST_ONLY = r'\bPERSIST_ONLY\b'
+    DEFAULT = r'\bDEFAULT\b'
+    IF_EXISTS = r'\bIF[\s]+EXISTS\b'
 
     # SELECT
 
@@ -97,6 +122,8 @@ class SQLLexer(Lexer):
     HAVING = r'\bHAVING\b'
     ORDER_BY = r'\bORDER BY\b'
     STAR = r'\*'
+    FOR = r'\bFOR\b'
+    UPDATE = r'\bUPDATE\b'
 
     JOIN = r'\bJOIN\b'
     INNER = r'\bINNER\b'
@@ -110,6 +137,11 @@ class SQLLexer(Lexer):
     UNION = r'\bUNION\b'
     ALL = r'\bALL\b'
 
+    # DML
+    INSERT = r'\bINSERT\b'
+    INTO = r'\bINTO\b'
+    VALUES = r'\bVALUES\b'
+
     # Special
     DOT = r'\.'
     COMMA = r','
@@ -138,6 +170,8 @@ class SQLLexer(Lexer):
     CONCAT = r'\|\|'
     BETWEEN = r'\bBETWEEN\b'
     WINDOW = r'\bWINDOW\b'
+    OVER = r'\bOVER\b'
+    PARTITION_BY = r'\bPARTITION BY\b'
 
     # Data types
     NULL = r'\bNULL\b'
@@ -158,11 +192,13 @@ class SQLLexer(Lexer):
         t.value = int(t.value)
         return t
 
-    @_(r'"[^"]*"',
-       r"'[^']*'")
-    def STRING(self, t):
-        if t.value[0] == '"':
-            t.value = t.value.strip('\"')
-        else:
-            t.value = t.value.strip('\'')
+    @_(r"'[^']*'")
+    def QUOTE_STRING(self, t):
+        t.value = t.value.strip('\'')
         return t
+
+    @_(r'"[^"]*"')
+    def DQUOTE_STRING(self, t):
+        t.value = t.value.strip('\"')
+        return t
+
